@@ -523,8 +523,10 @@ class Monitor(QtWidgets.QLabel):
         self.model = model
 
     def update_label(self):
-        if self.variable in self.model.variables:
-            self.setText(self.variable + ": " + str(self.model[self.variable]))
+        if hasattr(self.model, self.variable):
+            self.setText(
+                self.variable + ": " + str(getattr(self.model, self.variable))
+            )
 
 
 class Checkbox(QtWidgets.QCheckBox):
@@ -724,8 +726,11 @@ def run(model):
     # Launch the application
     qapp.exec_()
 
+    # Temporarily disabling sys.exit(0), as
+    # it provokes an error / stack trace being shown
+
     # Application was closed, clean up and exit
-    sys.exit(0)
+    # sys.exit(0)
 
 
 def quick_run():
